This is a small wrapper around Github's [Octicons](https://primer.style/foundations/icons).

# Usage

```python
from pyocticons import octicon

icon = octicon("alert", 24)
```


# License

All Icons are (c) GitHub, Inc. and licensed under the MIT License, see: https://github.com/primer/octicons





